@@ -2,10 +2,10 @@ package Statistics::Sequences;
 use strict;
 use warnings FATAL => 'all';
 use Carp qw(croak cluck);
-use Statistics::Data 0.08;
+use Statistics::Data 0.09;
 use base qw(Statistics::Data);
 use Scalar::Util qw(looks_like_number);
-our $VERSION = '0.12';
+$Statistics::Sequences::VERSION = '0.13';
 
 =pod
 
@@ -15,11 +15,11 @@ Statistics::Sequences - Manage sequences (ordered list of literals) for testing
 
 =head1 VERSION
 
-This is documentation for Version 0.12 of Statistics::Sequences.
+This is documentation for Version 0.13 of Statistics::Sequences.
 
 =head1 SYNOPSIS
 
- use Statistics::Sequences 0.12;
+ use Statistics::Sequences 0.13;
  $seq = Statistics::Sequences->new();
  my @data = (1, 'a', 'a', 1); # ordered list of literal scalars (numbers, strings), as permitted by specific test
  $seq->load(\@data); # or @data or dataname => \@data
@@ -67,7 +67,8 @@ Return the observed value of the statistic for the L<load|Statistics::Sequences/
 
 =cut
 
-sub observed { return _feedme('observed', @_); } *observation = \&observed;
+sub observed { return _feedme( 'observed', @_ ); }
+*observation = \&observed;
 
 =head2 expected, expectation
 
@@ -78,7 +79,8 @@ Return the expected value of the statistic for the L<load|Statistics::Sequences/
 
 =cut
 
-sub expected { return _feedme('expected', @_); } *expectation = \&expected;
+sub expected { return _feedme( 'expected', @_ ); }
+*expectation = \&expected;
 
 =head2 variance
 
@@ -89,7 +91,7 @@ Returns the expected range of deviation in the statistic's observed value for th
 
 =cut
 
-sub variance { return _feedme('variance', @_); }
+sub variance { return _feedme( 'variance', @_ ); }
 
 =head2 obsdev, observed_deviation
 
@@ -128,7 +130,8 @@ Return the deviation ratio: observed deviation to standard deviation. Use argume
 
 =cut
 
-sub zscore { return _feedme('zscore', @_); } *z_value = \&zscore;
+sub zscore { return _feedme( 'zscore', @_ ); }
+*z_value = \&zscore;
 
 =head2 p_value, test
 
@@ -181,7 +184,8 @@ B<Runs>, B<Turns> : There are presently no specific requirements nor options for
 
 =cut
 
-sub p_value { return _feedme('p_value', @_); } *test = \&p_value;
+sub p_value { return _feedme( 'p_value', @_ ); }
+*test = \&p_value;
 
 =head2 stats_hash
 
@@ -192,21 +196,25 @@ Returns a hashref with values for any of the descriptives and probability value
 =cut
 
 sub stats_hash {
-    my $self = shift;
-    my $args = ref $_[0] ? $_[0] : {@_};
-    my @methods = keys %{$args->{'values'}};
+    my $self         = shift;
+    my $args         = ref $_[0] ? $_[0] : {@_};
+    my @methods      = keys %{ $args->{'values'} };
     my (%stats_hash) = ();
     no strict 'refs';
-    foreach my $method(@methods) {
-        if ($args->{'values'}->{$method} == 1) {
-            eval {$stats_hash{$method} = $self->$method($args);};
-            croak "Method $method is not defined or correctly called for " . __PACKAGE__ if $@;
+    foreach my $method (@methods) {
+        if ( $args->{'values'}->{$method} == 1 ) {
+            eval { $stats_hash{$method} = $self->$method($args); };
+            croak "Method $method is not defined or correctly called for "
+              . __PACKAGE__
+              if $@;
         }
     }
-    if (! scalar keys %stats_hash) { # get default stats:
-        foreach my $method(qw/observed p_value/) {
-            eval {$stats_hash{$method} = $self->$method($args);};
-            croak "Method $method is not defined or correctly called for " . __PACKAGE__ if $@;
+    if ( !scalar keys %stats_hash ) {    # get default stats:
+        foreach my $method (qw/observed p_value/) {
+            eval { $stats_hash{$method} = $self->$method($args); };
+            croak "Method $method is not defined or correctly called for "
+              . __PACKAGE__
+              if $@;
         }
     }
     return \%stats_hash;
@@ -218,7 +226,7 @@ sub stats_hash {
 
 I<Alias>: B<print_summary>
 
-Print results of the last-conducted test to STDOUT. By default, if no parameters to C<dump> are passed, a single line of test statistics are printed. Options are as follows.
+Print results of the last-conducted test to STDOUT. By default, if no parameters to C<dump> are passed, a single line of test statistics is printed. Options are as follows.
 
 =over 8
 
@@ -259,40 +267,45 @@ Specify rounding of the probability associated with the I<z>-value to so many di
 =cut
 
 sub dump {
-    my $self = shift;
-    my $args = ref $_[0] ? $_[0] : {@_};
+    my $self       = shift;
+    my $args       = ref $_[0] ? $_[0] : {@_};
     my $stats_hash = $self->stats_hash($args);
     $args->{'format'} ||= 'csv';
-    my @standard_methods = (qw/observed expected variance obsdev stdev z_value p_value/);
-    my ($maxlen, @strs, @headers, @wanted_methods) = (0);
-    foreach my $method(@standard_methods) { # set up what has been requested in a meaningful order:
-        push(@wanted_methods, $method) if defined $stats_hash->{$method};
+    my @standard_methods =
+      (qw/observed expected variance obsdev stdev z_value p_value/);
+    my ( $maxlen, @strs, @headers, @wanted_methods ) = (0);
+    foreach my $method (@standard_methods)
+    {    # set up what has been requested in a meaningful order:
+        push( @wanted_methods, $method ) if defined $stats_hash->{$method};
     }
-    foreach my $method(keys %{$stats_hash}) {
-        push(@wanted_methods, $method) if ! grep/$method/, @wanted_methods;
+    foreach my $method ( keys %{$stats_hash} )
+    {    # add any extra "non-standard" methods
+        push( @wanted_methods, $method ) if !grep /$method/, @wanted_methods;
     }
-    foreach my $method(@wanted_methods) {
+    foreach my $method (@wanted_methods) {
         my $val = delete $stats_hash->{$method};
         my $len;
-        if ($method eq 'p_value') {
-            $val = _precisioned($args->{'precision_p'}, $val);
-            $val .= ($val < .05 ? ($val < .01 ? q{**} : q{*} ) : q{}) if $args->{'flag'};
+        if ( $method eq 'p_value' ) {
+            $val = _precisioned( $args->{'precision_p'}, $val );
+            $val .= ( $val < .05 ? ( $val < .01 ? q{**} : q{*} ) : q{} )
+              if $args->{'flag'};
         }
         else {
-            if (ref $val) {
-                if (ref $val eq 'HASH') {
+            if ( ref $val ) {
+                if ( ref $val eq 'HASH' ) {
                     my %vals = %{$val};
                     $val = q{};
                     my $delim = $args->{'format'} eq 'table' ? "\n" : q{,};
-                    my ($str, $this_len) = (q{});
-                    while (my($k, $v) = each %vals) {
-                        $str = "'$k' = $v";
+                    my ( $str, $this_len ) = (q{});
+                    while ( my ( $k, $v ) = each %vals ) {
+                        $str      = "'$k' = $v";
                         $this_len = length($str);
-                        $len = $this_len if not defined $len or $this_len > $len;
+                        $len      = $this_len
+                          if not defined $len or $this_len > $len;
                         $val .= $str;
                         $val .= $delim;
                     }
-                    if ($args->{'format'} ne 'table') {
+                    if ( $args->{'format'} ne 'table' ) {
                         chop $val;
                         $val = '(' . $val . ')';
                     }
@@ -301,39 +314,42 @@ sub dump {
                     $val = join q{, }, @{$val};
                 }
             }
-            elsif(looks_like_number($val)) {
-                $val = _precisioned($args->{'precision_s'}, $val);
+            elsif ( looks_like_number($val) ) {
+                $val = _precisioned( $args->{'precision_s'}, $val );
             }
         }
         push @headers, $method;
-        push(@strs, $val);
-        $len = length $val if ! defined $len;
-        $maxlen = $len if $len > $maxlen;
+        push( @strs, $val );
+        $len    = length $val if !defined $len;
+        $maxlen = $len        if $len > $maxlen;
     }
-    if ($args->{'format'} eq 'table') {
+    if ( $args->{'format'} eq 'table' ) {
         $maxlen = 8 if $maxlen < 8;
-        my $title = $args->{'verbose'} ? ucfirst($args->{'stat'}) . " statistics\n" : q{};
+        my $title =
+          $args->{'verbose'}
+          ? ucfirst( $args->{'stat'} ) . " statistics\n"
+          : q{};
         print $title or croak 'Cannot print title for data-table';
         my @hh = ();
-        push( @hh, [$maxlen, $_]) foreach @headers;
+        push( @hh, [ $maxlen, $_ ] ) foreach @headers;
         require Text::SimpleTable;
         my $tbl = Text::SimpleTable->new(@hh);
         $tbl->row(@strs);
         print $tbl->draw or croak 'Cannot print data-table';
     }
-    elsif ($args->{'format'} eq 'labline') {
+    elsif ( $args->{'format'} eq 'labline' ) {
         my @hh;
-        for (my $i = 0; $i <= $#strs; $i++) {
+        for ( my $i = 0 ; $i <= $#strs ; $i++ ) {
             $hh[$i] = "$headers[$i] = $strs[$i]";
         }
-        my $str = join(q{, }, @hh);
-        if ($args->{'verbose'}) {
-            $str = ucfirst($args->{'stat'}) . ': ' . $str;
+        my $str = join( q{, }, @hh );
+        if ( $args->{'verbose'} ) {
+            $str = ucfirst( $args->{'stat'} ) . ': ' . $str;
         }
         print {*STDOUT} $str, "\n" or croak 'Cannot print data-string';
     }
-    else { # csv
-        print join(q{,}, @strs) or croak 'Cannot print data-string'
+    else {    # csv
+        print join( q{,}, @strs ) or croak 'Cannot print data-string';
     }
     return;
 }
@@ -350,26 +366,33 @@ Prints to STDOUT a space-separated line of the tested data - as dichotomized and
 # PRIVATMETHODEN
 
 sub _feedme {
-    my $method = shift;
-    my $self = shift;
-    my $args = ref $_[0] ? $_[0] : {@_};
+    my $method   = shift;
+    my $self     = shift;
+    my $args     = ref $_[0] ? $_[0] : {@_};
     my $statname = $args->{'stat'} || q{};
-    my $class = __PACKAGE__ . q{::} . ucfirst($statname);
+    my $class    = __PACKAGE__ . q{::} . ucfirst($statname);
     eval "require $class";
-    croak __PACKAGE__, " error: Requested sequences module '$class' is not valid/available. You might need to install '$class'" if $@;
-    my ($val, $nself) = (q{}, {});
+    croak __PACKAGE__,
+" error: Requested sequences module '$class' is not valid/available. You might need to install '$class'"
+      if $@;
+    my ( $val, $nself ) = ( q{}, {} );
+
     #my $nself = {};
-    bless($nself, $class);#$nself = $class->new();
+    bless( $nself, $class );    #$nself = $class->new();
     $nself->{$_} = $self->{$_} foreach keys %{$self};
     no strict 'refs';
-    eval '$val = $nself->$method($args)'; # but does not trap "deep recursion" if method not defined
-    croak __PACKAGE__, " error: Method '$method' is not defined for $class" if $@;
+    eval '$val = $nself->$method($args)'
+      ;    # but does not trap "deep recursion" if method not defined
+    croak __PACKAGE__, " error: Method '$method' is not defined for $class"
+      if $@;
     $self->{'stat'} = $statname;
     return $val;
 }
 
 sub _precisioned {
-    return $_[0] ? sprintf(q{%.} . $_[0] . 'f', $_[1]) : (defined $_[1] ? $_[1] : q{}); # don't lose any zero
+    return $_[0]
+      ? sprintf( q{%.} . $_[0] . 'f', $_[1] )
+      : ( defined $_[1] ? $_[1] : q{} );    # don't lose any zero
 }
 
 =head1 BUNDLING
@@ -380,11 +403,39 @@ This module C<use>s its sub-modules implicitly - so a bundled program using this
 
 Roderick Garton, C<< <rgarton at cpan.org> >>
 
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Statistics::Sequences
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Statistics-Sequences-0.13>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Statistics-Sequences-0.13>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Statistics-Sequences-0.13>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Statistics-Sequences-0.13/>
+
+=back
+
 =head1 LICENSE AND COPYRIGHT
 
 =over 4
 
-=item Copyright (c) 2006-2013 Roderick Garton
+=item Copyright (c) 2006-2015 Roderick Garton
 
 This program is free software. It may be used, redistributed and/or modified under the same terms as Perl-5.6.1 (or later) (see L<http://www.perl.com/perl/misc/Artistic.html>).
 
@@ -396,4 +447,4 @@ To the maximum extent permitted by applicable law, the author of this module dis
 
 =cut
 
-1; # end of Statistics::Sequences
+1;    # end of Statistics::Sequences
